@@ -1,8 +1,8 @@
 #[cfg(feature = "ape")]
-use crate::ape::tag::ape_tag::ApeTagRef;
-use crate::error::{LoftyError, Result};
+use crate::ape::tag::ape_tag;
+use crate::error::{ErrorKind, LoftyError, Result};
 #[cfg(feature = "id3v1")]
-use crate::id3::v1::tag::Id3v1TagRef;
+use crate::id3::v1;
 #[allow(unused_imports)]
 use crate::types::tag::{Tag, TagType};
 
@@ -12,9 +12,9 @@ use std::fs::File;
 pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 	match tag.tag_type() {
 		#[cfg(feature = "ape")]
-		TagType::Ape => Into::<ApeTagRef>::into(tag).write_to(data),
+		TagType::Ape => Into::<ape_tag::ApeTagRef>::into(tag).write_to(data),
 		#[cfg(feature = "id3v1")]
-		TagType::Id3v1 => Into::<Id3v1TagRef>::into(tag).write_to(data),
-		_ => Err(LoftyError::UnsupportedTag),
+		TagType::Id3v1 => Into::<v1::tag::Id3v1TagRef>::into(tag).write_to(data),
+		_ => Err(LoftyError::new(ErrorKind::UnsupportedTag)),
 	}
 }
