@@ -12,7 +12,7 @@ pub struct Id3v2TagFlags {
 	/// Indicates that the tag includes a footer
 	///
 	/// NOTE: This will have no effect when writing
-	pub footer: bool,
+	pub footer: bool, // TODO: Should this be written? Seems useless, but it isn't much work.
 	/// Whether or not to include a CRC-32 in the extended header
 	///
 	/// This is calculated if the tag is written
