@@ -1,5 +1,5 @@
-use crate::error::{LoftyError, Result};
-use crate::id3::v2::frame::{FrameFlags, FrameRef};
+use crate::error::{Id3v2Error, Id3v2ErrorKind, Result};
+use crate::id3::v2::frame::{FrameFlags, FrameRef, FrameValue};
 use crate::id3::v2::synch_u32;
 
 use std::io::Write;
@@ -14,6 +14,7 @@ where
 	W: Write,
 {
 	for frame in frames {
+		verify_frame(&frame)?;
 		let value = frame.value.as_bytes()?;
 
 		write_frame(writer, frame.id, frame.flags, &value)?;
@@ -22,6 +23,34 @@ where
 	Ok(())
 }
 
+fn verify_frame(frame: &FrameRef) -> Result<()> {
+	match (frame.id, frame.value.as_ref()) {
+		("APIC", FrameValue::Picture { .. })
+		| ("USLT", FrameValue::UnSyncText(_))
+		| ("COMM", FrameValue::Comment(_))
+		| ("TXXX", FrameValue::UserText(_))
+		| ("WXXX", FrameValue::UserURL(_))
+		| (_, FrameValue::Binary(_))
+		| ("WFED" | "GRP1", FrameValue::Text { .. }) => Ok(()),
+		(id, FrameValue::Text { .. }) if id.starts_with('T') => Ok(()),
+		(id, FrameValue::URL(_)) if id.starts_with('W') => Ok(()),
+		(id, frame_value) => Err(Id3v2Error::new(Id3v2ErrorKind::BadFrame(
+			id.to_string(),
+			match frame_value {
+				FrameValue::Comment(_) => "Comment",
+				FrameValue::UnSyncText(_) => "UnSyncText",
+				FrameValue::Text { .. } => "Text",
+				FrameValue::UserText(_) => "UserText",
+				FrameValue::URL(_) => "URL",
+				FrameValue::UserURL(_) => "UserURL",
+				FrameValue::Picture { .. } => "Picture",
+				FrameValue::Binary(_) => "Binary",
+			},
+		))
+		.into()),
+	}
+}
+
 fn write_frame<W>(writer: &mut W, name: &str, flags: FrameFlags, value: &[u8]) -> Result<()>
 where
 	W: Write,
@@ -58,9 +87,10 @@ where
 	let data_length_indicator = flags.data_length_indicator;
 
 	if method_symbol > 0x80 {
-		return Err(LoftyError::Id3v2(
+		return Err(Id3v2Error::new(Id3v2ErrorKind::Other(
 			"Attempted to write an encrypted frame with an invalid method symbol (> 0x80)",
-		));
+		))
+		.into());
 	}
 
 	if data_length_indicator.0 && data_length_indicator.1 > 0 {
@@ -72,9 +102,10 @@ where
 		return Ok(());
 	}
 
-	Err(LoftyError::Id3v2(
+	Err(Id3v2Error::new(Id3v2ErrorKind::Other(
 		"Attempted to write an encrypted frame without a data length indicator",
 	))
+	.into())
 }
 
 fn write_frame_header<W>(writer: &mut W, name: &str, len: u32, flags: FrameFlags) -> Result<()>
