@@ -1,11 +1,6 @@
-use crate::error::{LoftyError, Result};
+use crate::error::{ErrorKind, LoftyError, Result};
 #[cfg(feature = "id3v2")]
-use crate::id3::v2::{
-	tag::{tag_frames, Id3v2TagRef},
-	Id3v2TagFlags,
-};
-#[cfg(feature = "aiff_text_chunks")]
-use crate::iff::aiff::tag::AiffTextChunksRef;
+use crate::id3::v2;
 use crate::types::item::ItemKey;
 #[allow(unused_imports)]
 use crate::types::tag::{Tag, TagType};
@@ -16,7 +11,7 @@ use std::fs::File;
 pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 	match tag.tag_type() {
 		#[cfg(feature = "aiff_text_chunks")]
-		TagType::AiffText => AiffTextChunksRef::new(
+		TagType::AiffText => super::tag::AiffTextChunksRef::new(
 			tag.get_string(&ItemKey::TrackTitle),
 			tag.get_string(&ItemKey::TrackArtist),
 			tag.get_string(&ItemKey::CopyrightMessage),
@@ -25,7 +20,10 @@ pub(crate) fn write_to(data: &mut File, tag: &Tag) -> Result<()> {
 		)
 		.write_to(data),
 		#[cfg(feature = "id3v2")]
-		TagType::Id3v2 => Id3v2TagRef::new(Id3v2TagFlags::default(), tag_frames(tag)).write_to(data),
-		_ => Err(LoftyError::UnsupportedTag),
+		TagType::Id3v2 => {
+			v2::tag::Id3v2TagRef::new(v2::Id3v2TagFlags::default(), v2::tag::tag_frames(tag))
+				.write_to(data)
+		},
+		_ => Err(LoftyError::new(ErrorKind::UnsupportedTag)),
 	}
 }
