@@ -1,4 +1,5 @@
-use crate::error::{LoftyError, Result};
+use crate::error::{FileDecodingError, Result};
+use crate::types::file::FileType;
 use crate::types::properties::FileProperties;
 
 use std::time::Duration;
@@ -32,6 +33,7 @@ pub struct WavProperties {
 	overall_bitrate: u32,
 	audio_bitrate: u32,
 	sample_rate: u32,
+	bit_depth: u8,
 	channels: u8,
 }
 
@@ -42,6 +44,7 @@ impl From<WavProperties> for FileProperties {
 			overall_bitrate: Some(input.overall_bitrate),
 			audio_bitrate: Some(input.audio_bitrate),
 			sample_rate: Some(input.sample_rate),
+			bit_depth: Some(input.bit_depth),
 			channels: Some(input.channels),
 		}
 	}
@@ -55,6 +58,7 @@ impl WavProperties {
 		overall_bitrate: u32,
 		audio_bitrate: u32,
 		sample_rate: u32,
+		bit_depth: u8,
 		channels: u8,
 	) -> Self {
 		Self {
@@ -63,6 +67,7 @@ impl WavProperties {
 			overall_bitrate,
 			audio_bitrate,
 			sample_rate,
+			bit_depth,
 			channels,
 		}
 	}
@@ -87,6 +92,11 @@ impl WavProperties {
 		self.sample_rate
 	}
 
+	/// Bits per sample
+	pub fn bit_depth(&self) -> u8 {
+		self.bit_depth
+	}
+
 	/// Channel count
 	pub fn channels(&self) -> u8 {
 		self.channels
@@ -108,40 +118,53 @@ pub(super) fn read_properties(
 	let channels = fmt.read_u16::<LittleEndian>()? as u8;
 
 	if channels == 0 {
-		return Err(LoftyError::Wav("File contains 0 channels"));
+		return Err(FileDecodingError::new(FileType::WAV, "File contains 0 channels").into());
 	}
 
 	let sample_rate = fmt.read_u32::<LittleEndian>()?;
 	let bytes_per_second = fmt.read_u32::<LittleEndian>()?;
 
-	// Skip 2 bytes
-	// Block align (2)
-	fmt.read_u16::<LittleEndian>()?;
+	let block_align = fmt.read_u16::<LittleEndian>()?;
 
 	let bits_per_sample = fmt.read_u16::<LittleEndian>()?;
+	let bytes_per_sample = block_align / u16::from(channels);
+
+	let mut bit_depth = if bits_per_sample > 0 {
+		bits_per_sample as u8
+	} else {
+		(bytes_per_sample * 8) as u8
+	};
 
 	if format_tag == EXTENSIBLE {
-		if fmt.len() < 40 {
-			return Err(LoftyError::Wav(
+		if fmt.len() + 16 < 40 {
+			return Err(FileDecodingError::new(
+				FileType::WAV,
 				"Extensible format identified, invalid \"fmt \" chunk size found (< 40)",
-			));
+			)
+			.into());
 		}
 
-		// Skip 8 bytes
 		// cbSize (Size of extra format information) (2)
+		let _cb_size = fmt.read_u16::<LittleEndian>()?;
 		// Valid bits per sample (2)
+		let valid_bits_per_sample = fmt.read_u16::<LittleEndian>()?;
 		// Channel mask (4)
-		fmt.read_u64::<LittleEndian>()?;
+		let _channel_mask = fmt.read_u32::<LittleEndian>()?;
 
+		if valid_bits_per_sample > 0 {
+			bit_depth = valid_bits_per_sample as u8;
+		}
 		format_tag = fmt.read_u16::<LittleEndian>()?;
 	}
 
 	let non_pcm = format_tag != PCM && format_tag != IEEE_FLOAT;
 
 	if non_pcm && total_samples == 0 {
-		return Err(LoftyError::Wav(
+		return Err(FileDecodingError::new(
+			FileType::WAV,
 			"Non-PCM format identified, no \"fact\" chunk found",
-		));
+		)
+		.into());
 	}
 
 	if bits_per_sample > 0 {
@@ -152,15 +175,18 @@ pub(super) fn read_properties(
 
 	let (duration, overall_bitrate, audio_bitrate) = if sample_rate > 0 && total_samples > 0 {
 		let length = (u64::from(total_samples) * 1000) / u64::from(sample_rate);
+		if length == 0 {
+			(Duration::ZERO, 0, 0)
+		} else {
+			let overall_bitrate = ((file_length * 8) / length) as u32;
+			let audio_bitrate = (u64::from(stream_len * 8) / length) as u32;
 
-		let overall_bitrate = ((file_length * 8) / length) as u32;
-		let audio_bitrate = (u64::from(stream_len * 8) / length) as u32;
-
-		(
-			Duration::from_millis(length),
-			overall_bitrate,
-			audio_bitrate,
-		)
+			(
+				Duration::from_millis(length),
+				overall_bitrate,
+				audio_bitrate,
+			)
+		}
 	} else if bytes_per_second > 0 {
 		let length = (u64::from(stream_len) * 1000) / u64::from(bytes_per_second);
 
@@ -186,6 +212,7 @@ pub(super) fn read_properties(
 		overall_bitrate,
 		audio_bitrate,
 		sample_rate,
+		bit_depth,
 		channels,
 	})
 }
