@@ -1,5 +1,6 @@
 use super::constants::{BITRATES, PADDING_SIZES, SAMPLES, SAMPLE_RATES, SIDE_INFORMATION_SIZES};
-use crate::error::{LoftyError, Result};
+use crate::error::{FileDecodingError, Result};
+use crate::types::file::FileType;
 
 use std::io::Read;
 
@@ -9,6 +10,39 @@ pub(crate) fn verify_frame_sync(frame_sync: [u8; 2]) -> bool {
 	frame_sync[0] == 0xFF && frame_sync[1] >> 5 == 0b111
 }
 
+// Searches for a frame sync (11 set bits) in the reader.
+// The search starts at the beginning of the reader and returns the index relative to this beginning.
+// This will return the first match, if one is found.
+//
+// Note that the search searches in 8 bit steps, i.e. the first 8 bits need to be byte aligned.
+pub(crate) fn search_for_frame_sync<R>(input: &mut R) -> std::io::Result<Option<u64>>
+where
+	R: Read,
+{
+	let mut iterator = input.bytes();
+	let mut buffer = [0u8; 2];
+	// Read the first byte, as each iteration expects that buffer 0 was set from a previous iteration.
+	// This is not the case in the first iteration, which is therefore a special case.
+	if let Some(byte) = iterator.next() {
+		buffer[0] = byte?;
+	}
+	// Create a stream of overlapping 2 byte pairs
+	//
+	// Example:
+	// [0x01, 0x02, 0x03, 0x04] should be analyzed as
+	// [0x01, 0x02], [0x02, 0x03], [0x03, 0x04]
+	for (index, byte) in iterator.enumerate() {
+		buffer[1] = byte?;
+		// Check the two bytes in the buffer
+		if verify_frame_sync(buffer) {
+			return Ok(Some(index as u64));
+		}
+		// If they do not match, copy the last byte in the buffer to the front for the next iteration
+		buffer[0] = buffer[1];
+	}
+	Ok(None)
+}
+
 #[derive(PartialEq, Copy, Clone, Debug)]
 #[allow(missing_docs)]
 /// MPEG Audio version
@@ -74,7 +108,13 @@ impl Header {
 			0 => MpegVersion::V2_5,
 			2 => MpegVersion::V2,
 			3 => MpegVersion::V1,
-			_ => return Err(LoftyError::Mp3("Frame header has an invalid version")),
+			_ => {
+				return Err(FileDecodingError::new(
+					FileType::MP3,
+					"Frame header has an invalid version",
+				)
+				.into())
+			},
 		};
 
 		let version_index = if version == MpegVersion::V1 { 0 } else { 1 };
@@ -83,7 +123,13 @@ impl Header {
 			1 => Layer::Layer3,
 			2 => Layer::Layer2,
 			3 => Layer::Layer1,
-			_ => return Err(LoftyError::Mp3("Frame header uses a reserved layer")),
+			_ => {
+				return Err(FileDecodingError::new(
+					FileType::MP3,
+					"Frame header uses a reserved layer",
+				)
+				.into())
+			},
 		};
 
 		let layer_index = (layer as usize).saturating_sub(1);
@@ -113,7 +159,7 @@ impl Header {
 			1 => ChannelMode::JointStereo,
 			2 => ChannelMode::DualChannel,
 			3 => ChannelMode::SingleChannel,
-			_ => return Err(LoftyError::Mp3("Unreachable error")),
+			_ => unreachable!(),
 		};
 
 		let data_start = SIDE_INFORMATION_SIZES[version_index][channel_mode as usize] + 4;
@@ -163,16 +209,22 @@ impl XingHeader {
 		match &header {
 			b"Xing" | b"Info" => {
 				if reader_len < 16 {
-					return Err(LoftyError::Mp3("Xing header has an invalid size (< 16)"));
+					return Err(FileDecodingError::new(
+						FileType::MP3,
+						"Xing header has an invalid size (< 16)",
+					)
+					.into());
 				}
 
 				let mut flags = [0; 4];
 				reader.read_exact(&mut flags)?;
 
 				if flags[3] & 0x03 != 0x03 {
-					return Err(LoftyError::Mp3(
+					return Err(FileDecodingError::new(
+						FileType::MP3,
 						"Xing header doesn't have required flags set (0x0001 and 0x0002)",
-					));
+					)
+					.into());
 				}
 
 				let frames = reader.read_u32::<BigEndian>()?;
@@ -182,7 +234,11 @@ impl XingHeader {
 			},
 			b"VBRI" => {
 				if reader_len < 32 {
-					return Err(LoftyError::Mp3("VBRI header has an invalid size (< 32)"));
+					return Err(FileDecodingError::new(
+						FileType::MP3,
+						"VBRI header has an invalid size (< 32)",
+					)
+					.into());
 				}
 
 				// Skip 6 bytes
@@ -196,7 +252,29 @@ impl XingHeader {
 
 				Ok(Self { frames, size })
 			},
-			_ => Err(LoftyError::Mp3("No Xing, LAME, or VBRI header located")),
+			_ => Err(FileDecodingError::new(
+				FileType::MP3,
+				"No Xing, LAME, or VBRI header located",
+			)
+			.into()),
 		}
 	}
 }
+
+#[cfg(test)]
+mod tests {
+	#[test]
+	fn search_for_frame_sync() {
+		fn test(data: &[u8], expected_result: Option<u64>) {
+			use super::search_for_frame_sync;
+			assert_eq!(
+				search_for_frame_sync(&mut Box::new(data)).unwrap(),
+				expected_result
+			);
+		}
+
+		test(&[0xFF, 0xFB, 0x00], Some(0));
+		test(&[0x00, 0x00, 0x01, 0xFF, 0xFB], Some(3));
+		test(&[0x01, 0xFF], None);
+	}
+}
