@@ -1,7 +1,8 @@
 use super::atom_info::{AtomIdent, AtomInfo};
 use super::read::{nested_atom, skip_unneeded};
 use super::trak::Trak;
-use crate::error::{LoftyError, Result};
+use crate::error::{ErrorKind, FileDecodingError, LoftyError, Result};
+use crate::types::file::FileType;
 use crate::types::properties::FileProperties;
 
 use std::io::{Cursor, Read, Seek, SeekFrom};
@@ -32,6 +33,7 @@ pub struct Mp4Properties {
 	overall_bitrate: u32,
 	audio_bitrate: u32,
 	sample_rate: u32,
+	bit_depth: Option<u8>,
 	channels: u8,
 }
 
@@ -42,6 +44,7 @@ impl From<Mp4Properties> for FileProperties {
 			overall_bitrate: Some(input.overall_bitrate),
 			audio_bitrate: Some(input.audio_bitrate),
 			sample_rate: Some(input.sample_rate),
+			bit_depth: input.bit_depth,
 			channels: Some(input.channels),
 		}
 	}
@@ -55,6 +58,7 @@ impl Mp4Properties {
 		overall_bitrate: u32,
 		audio_bitrate: u32,
 		sample_rate: u32,
+		bit_depth: Option<u8>,
 		channels: u8,
 	) -> Self {
 		Self {
@@ -63,6 +67,7 @@ impl Mp4Properties {
 			overall_bitrate,
 			audio_bitrate,
 			sample_rate,
+			bit_depth,
 			channels,
 		}
 	}
@@ -87,6 +92,11 @@ impl Mp4Properties {
 		self.sample_rate
 	}
 
+	/// Bits per sample
+	pub fn bit_depth(&self) -> Option<u8> {
+		self.bit_depth
+	}
+
 	/// Channel count
 	pub fn channels(&self) -> u8 {
 		self.channels
@@ -159,40 +169,44 @@ where
 	}
 
 	if !audio_track {
-		return Err(LoftyError::Mp4("File contains no audio tracks"));
+		return Err(FileDecodingError::new(FileType::MP4, "File contains no audio tracks").into());
 	}
 
-	let duration = match mdhd {
-		Some(mdhd) => {
-			data.seek(SeekFrom::Start(mdhd.start + 8))?;
-
-			let version = data.read_u8()?;
-			let _flags = data.read_uint::<BigEndian>(3)?;
-
-			let (timescale, duration) = if version == 1 {
-				// We don't care about these two values
-				let _creation_time = data.read_u64::<BigEndian>()?;
-				let _modification_time = data.read_u64::<BigEndian>()?;
-
-				let timescale = data.read_u32::<BigEndian>()?;
-				let duration = data.read_u64::<BigEndian>()?;
-
-				(timescale, duration)
-			} else {
-				let _creation_time = data.read_u32::<BigEndian>()?;
-				let _modification_time = data.read_u32::<BigEndian>()?;
-
-				let timescale = data.read_u32::<BigEndian>()?;
-				let duration = data.read_u32::<BigEndian>()?;
-
-				(timescale, u64::from(duration))
-			};
-
-			Duration::from_millis(duration * 1000 / u64::from(timescale))
+	let mdhd = match mdhd {
+		Some(mdhd) => mdhd,
+		None => {
+			return Err(LoftyError::new(ErrorKind::BadAtom(
+				"Expected atom \"trak.mdia.mdhd\"",
+			)))
 		},
-		None => return Err(LoftyError::BadAtom("Expected atom \"trak.mdia.mdhd\"")),
 	};
 
+	data.seek(SeekFrom::Start(mdhd.start + 8))?;
+
+	let version = data.read_u8()?;
+	let _flags = data.read_uint::<BigEndian>(3)?;
+
+	let (timescale, duration) = if version == 1 {
+		// We don't care about these two values
+		let _creation_time = data.read_u64::<BigEndian>()?;
+		let _modification_time = data.read_u64::<BigEndian>()?;
+
+		let timescale = data.read_u32::<BigEndian>()?;
+		let duration = data.read_u64::<BigEndian>()?;
+
+		(timescale, duration)
+	} else {
+		let _creation_time = data.read_u32::<BigEndian>()?;
+		let _modification_time = data.read_u32::<BigEndian>()?;
+
+		let timescale = data.read_u32::<BigEndian>()?;
+		let duration = data.read_u32::<BigEndian>()?;
+
+		(timescale, u64::from(duration))
+	};
+
+	let duration = Duration::from_millis(duration * 1000 / u64::from(timescale));
+
 	// We create the properties here, since it is possible the other information isn't available
 	let mut properties = Mp4Properties {
 		codec: Mp4Codec::Unknown(String::new()),
@@ -200,6 +214,7 @@ where
 		overall_bitrate: 0,
 		audio_bitrate: 0,
 		sample_rate: 0,
+		bit_depth: None,
 		channels: 0,
 	};
 
@@ -224,7 +239,7 @@ where
 				if let AtomIdent::Fourcc(ref fourcc) = atom.ident {
 					match fourcc {
 						b"mp4a" => mp4a_properties(&mut stsd_reader, &mut properties, file_length)?,
-						b"alac" => alac_properties(&mut stsd_reader, &mut properties)?,
+						b"alac" => alac_properties(&mut stsd_reader, &mut properties, file_length)?,
 						unknown => {
 							if let Ok(codec) = std::str::from_utf8(unknown) {
 								properties.codec = Mp4Codec::Unknown(codec.to_string())
@@ -280,7 +295,7 @@ where
 				// Descriptor length (1)
 				// Elementary stream ID (2)
 				// Flags (1)
-				let _info = stsd.read_u32::<BigEndian>()?;
+				stsd.seek(SeekFrom::Current(4))?;
 
 				// There is another descriptor embedded in the previous one
 				let mut specific_config = [0; 4];
@@ -290,12 +305,11 @@ where
 				if specific_config == [0x04, 0x80, 0x80, 0x80] {
 					// Skipping 10 bytes
 					// Descriptor length (1)
-					// MPEG4 Audio (1)
+					// Codec (1)
 					// Stream type (1)
 					// Buffer size (3)
 					// Max bitrate (4)
-					let mut info = [0; 10];
-					stsd.read_exact(&mut info)?;
+					stsd.seek(SeekFrom::Current(10))?;
 
 					let average_bitrate = stsd.read_u32::<BigEndian>()?;
 
@@ -314,7 +328,7 @@ where
 	Ok(())
 }
 
-fn alac_properties<R>(data: &mut R, properties: &mut Mp4Properties) -> Result<()>
+fn alac_properties<R>(data: &mut R, properties: &mut Mp4Properties, file_length: u64) -> Result<()>
 where
 	R: Read + Seek,
 {
@@ -336,15 +350,21 @@ where
 		if alac.ident == AtomIdent::Fourcc(*b"alac") {
 			properties.codec = Mp4Codec::ALAC;
 
-			// Skipping 13 bytes
+			// Skipping 9 bytes
 			// Version (4)
 			// Samples per frame (4)
 			// Compatible version (1)
+			data.seek(SeekFrom::Current(9))?;
+
 			// Sample size (1)
+			let sample_size = data.read_u8()?;
+			properties.bit_depth = Some(sample_size);
+
+			// Skipping 3 bytes
 			// Rice history mult (1)
 			// Rice initial history (1)
 			// Rice parameter limit (1)
-			data.seek(SeekFrom::Current(13))?;
+			data.seek(SeekFrom::Current(3))?;
 
 			properties.channels = data.read_u8()?;
 
@@ -353,7 +373,11 @@ where
 			// Max frame size (4)
 			data.seek(SeekFrom::Current(6))?;
 
-			properties.audio_bitrate = data.read_u32::<BigEndian>()?;
+			let overall_bitrate = u128::from(file_length * 8) / properties.duration.as_millis();
+			properties.overall_bitrate = overall_bitrate as u32;
+
+			// TODO: Determine bitrate from mdat
+			properties.audio_bitrate = data.read_u32::<BigEndian>()? / 1000;
 			properties.sample_rate = data.read_u32::<BigEndian>()?;
 		}
 	}
