@@ -1,5 +1,6 @@
 use super::find_last_page;
-use crate::error::{LoftyError, Result};
+use crate::error::{FileDecodingError, Result};
+use crate::types::file::FileType;
 use crate::types::properties::FileProperties;
 
 use std::io::{Read, Seek, SeekFrom};
@@ -26,6 +27,7 @@ impl From<OpusProperties> for FileProperties {
 			overall_bitrate: Some(input.overall_bitrate),
 			audio_bitrate: Some(input.audio_bitrate),
 			sample_rate: Some(input.input_sample_rate),
+			bit_depth: None,
 			channels: Some(input.channels),
 		}
 	}
@@ -113,7 +115,12 @@ where
 	last_page_abgp
 		.checked_sub(first_page_abgp + u64::from(pre_skip))
 		.map_or_else(
-			|| Err(LoftyError::Opus("File contains incorrect PCM values")),
+			|| {
+				Err(
+					FileDecodingError::new(FileType::Opus, "File contains incorrect PCM values")
+						.into(),
+				)
+			},
 			|frame_count| {
 				let length = frame_count * 1000 / 48000;
 				let duration = Duration::from_millis(length as u64);
