@@ -1,7 +1,7 @@
 #[cfg(feature = "vorbis_comments")]
 use super::tag::VorbisComments;
 use super::verify_signature;
-use crate::error::{LoftyError, Result};
+use crate::error::{ErrorKind, FileDecodingError, LoftyError, Result};
 #[cfg(feature = "vorbis_comments")]
 use crate::types::picture::Picture;
 
@@ -29,7 +29,12 @@ where
 
 	let vendor = match String::from_utf8(vendor) {
 		Ok(v) => v,
-		Err(_) => return Err(LoftyError::Ogg("File has an invalid vendor string")),
+		Err(_) => {
+			return Err(FileDecodingError::from_description(
+				"OGG: File has an invalid vendor string",
+			)
+			.into())
+		},
 	};
 
 	tag.vendor = vendor;
@@ -43,14 +48,25 @@ where
 		data.read_exact(&mut comment_bytes)?;
 
 		let comment = String::from_utf8(comment_bytes)?;
+		let mut comment_split = comment.splitn(2, '=');
 
-		let split: Vec<&str> = comment.splitn(2, '=').collect();
+		let key = match comment_split.next() {
+			Some(k) => k,
+			None => continue,
+		};
 
-		match &*split[0] {
-			"METADATA_BLOCK_PICTURE" => tag
-				.pictures
-				.push(Picture::from_flac_bytes(split[1].as_bytes(), true)?),
-			_ => tag.items.push((split[0].to_string(), split[1].to_string())),
+		// Make sure there was a separator present, otherwise just move on
+		if let Some(value) = comment_split.next() {
+			match key {
+				"METADATA_BLOCK_PICTURE" => tag
+					.pictures
+					.push(Picture::from_flac_bytes(value.as_bytes(), true)?),
+				// The valid range is 0x20..=0x7D not including 0x3D
+				k if k.chars().all(|c| (' '..='}').contains(&c) && c != '=') => {
+					tag.items.push((k.to_string(), value.to_string()))
+				},
+				_ => {}, // Discard invalid keys
+			}
 		}
 	}
 
@@ -73,7 +89,7 @@ where
 
 	while let Ok(page) = Page::read(data, false) {
 		if md_pages.len() > 125_829_120 {
-			return Err(LoftyError::TooMuchData);
+			return Err(LoftyError::new(ErrorKind::TooMuchData));
 		}
 
 		if page.header_type() & 0x01 == 1 {
