@@ -1,5 +1,6 @@
-use crate::error::{LoftyError, Result};
+use crate::error::{FileEncodingError, Result};
 use crate::ogg::constants::VORBIS_SETUP_HEAD;
+use crate::types::file::FileType;
 
 use std::fs::File;
 use std::io::{Cursor, Read, Seek, SeekFrom, Write};
@@ -48,7 +49,9 @@ pub(crate) fn write_to(
 	}
 
 	if !reached_md_end {
-		return Err(LoftyError::Vorbis("File ends with comment header"));
+		return Err(
+			FileEncodingError::new(FileType::Vorbis, "File ends with comment header").into(),
+		);
 	}
 
 	c.seek(SeekFrom::Start(comments_pos))?;
@@ -59,7 +62,9 @@ pub(crate) fn write_to(
 	}
 
 	if c.read_u8()? != 1 {
-		return Err(LoftyError::Vorbis("File is missing a framing bit"));
+		return Err(
+			FileEncodingError::new(FileType::Vorbis, "File is missing a framing bit").into(),
+		);
 	}
 
 	// Comments should be followed by the setup header
@@ -67,7 +72,9 @@ pub(crate) fn write_to(
 	c.read_exact(&mut header_ident)?;
 
 	if header_ident != VORBIS_SETUP_HEAD {
-		return Err(LoftyError::Vorbis("File is missing setup header"));
+		return Err(
+			FileEncodingError::new(FileType::Vorbis, "File is missing setup header").into(),
+		);
 	}
 
 	c.seek(SeekFrom::Current(-7))?;
@@ -82,7 +89,7 @@ pub(crate) fn write_to(
 
 		if i == pages_len {
 			// Add back the framing bit
-			p.extend(&[1]);
+			p.extend(&[1])?;
 
 			// The segment tables of current page and the setup header have to be combined
 			let mut seg_table = Vec::new();
@@ -98,9 +105,9 @@ pub(crate) fn write_to(
 
 			seg_table.insert(0, seg_table_len as u8);
 
-			let page = p.extend(&*setup);
+			let page = p.extend(&*setup)?;
 
-			let mut p_bytes = p.as_bytes();
+			let mut p_bytes = p.as_bytes()?;
 			let seg_count = p_bytes[26] as usize;
 
 			// Replace segment table and checksum
@@ -111,16 +118,16 @@ pub(crate) fn write_to(
 
 			if let Some(mut page) = page {
 				page.serial = ser;
-				page.gen_crc();
+				page.gen_crc()?;
 
-				writer.write_all(&*page.as_bytes())?;
+				writer.write_all(&*page.as_bytes()?)?;
 			}
 
 			break;
 		}
 
-		p.gen_crc();
-		writer.write_all(&*p.as_bytes())?;
+		p.gen_crc()?;
+		writer.write_all(&*p.as_bytes()?)?;
 	}
 
 	writer.write_all(&*remaining)?;
