@@ -7,6 +7,7 @@ pub struct FileProperties {
 	pub(crate) overall_bitrate: Option<u32>,
 	pub(crate) audio_bitrate: Option<u32>,
 	pub(crate) sample_rate: Option<u32>,
+	pub(crate) bit_depth: Option<u8>,
 	pub(crate) channels: Option<u8>,
 }
 
@@ -17,6 +18,7 @@ impl Default for FileProperties {
 			overall_bitrate: None,
 			audio_bitrate: None,
 			sample_rate: None,
+			bit_depth: None,
 			channels: None,
 		}
 	}
@@ -29,6 +31,7 @@ impl FileProperties {
 		overall_bitrate: Option<u32>,
 		audio_bitrate: Option<u32>,
 		sample_rate: Option<u32>,
+		bit_depth: Option<u8>,
 		channels: Option<u8>,
 	) -> Self {
 		Self {
@@ -36,6 +39,7 @@ impl FileProperties {
 			overall_bitrate,
 			audio_bitrate,
 			sample_rate,
+			bit_depth,
 			channels,
 		}
 	}
@@ -60,6 +64,11 @@ impl FileProperties {
 		self.sample_rate
 	}
 
+	/// Bits per sample (usually 16 or 24 bit)
+	pub fn bit_depth(&self) -> Option<u8> {
+		self.bit_depth
+	}
+
 	/// Channel count
 	pub fn channels(&self) -> Option<u8> {
 		self.channels
